@@ -1,7 +1,7 @@
 package Perinci::Sub::Normalize;
 
-our $DATE = '2015-01-07'; # DATE
-our $VERSION = '0.09'; # VERSION
+our $DATE = '2015-04-24'; # DATE
+our $VERSION = '0.10'; # VERSION
 
 use 5.010001;
 use strict;
@@ -43,6 +43,7 @@ sub _normalize{
             next KEY;
         }
 
+        # skip properties prefixed with _ (e.g. _comment)
         my $prop = $k;
         my $prop_proplist = $proplist->{$prop};
         if ($prop =~ /\A_/) {
@@ -51,6 +52,13 @@ sub _normalize{
             }
             next KEY;
         }
+
+        # normalize prop(LANG) to prop.alt.lang.LANG
+        if ($prop =~ /\A(.+)\((\w+)\)\z/) {
+            $nmeta->{"$1.alt.lang.$2"} = $meta->{$k};
+            next KEY;
+        }
+
         # try to load module that declare new props first
         if (!$opt_aup && !$prop_proplist) {
             if ($prop =~ /\A[A-Za-z][A-Za-z0-9_]*\z/) {
@@ -133,7 +141,7 @@ sub _normalize{
     $nmeta;
 }
 
-sub normalize_function_metadata {
+sub normalize_function_metadata($;$) {
     my ($meta, $opts) = @_;
 
     $opts //= {};
@@ -160,7 +168,7 @@ Perinci::Sub::Normalize - Normalize Rinci function metadata
 
 =head1 VERSION
 
-This document describes version 0.09 of Perinci::Sub::Normalize (from Perl distribution Perinci-Sub-Normalize), released on 2015-01-07.
+This document describes version 0.10 of Perinci::Sub::Normalize (from Perl distribution Perinci-Sub-Normalize), released on 2015-04-24.
 
 =head1 SYNOPSIS
 
